==> aroundme_0_5_2.zip: aroundme_0_5_2/aroundme/template/barnraiser_01/sn_blocked.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_blocked.php" method="post">

<table width="100%" border="0" cellspacing="0" cellpadding="0">
	<tr>

		<td width="560" valign="top">
			<div class="box_top">
				<?php echo $lang['hdr_blocked'];?><br />
			</div>
			
			<div class="box_mid" style="padding: 9px;">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<?php
				if (isset($blocked)) {
				foreach($blocked as $key => $i):
				?>
				<tr>
					<td>

						<?php echo $i['profile_nic'];?><br />
					</td>
					<td>
						<?php echo $i['block_datetime'];?><br />
					</td>
					<td>
						<?php echo $i['block_description'];?><br />
					</td>
					<td align="right">
						<a href="sn_blocked.php?unblock_user_id=<?php echo $i['user_id_blocked'];?>"><?php echo $lang['href_unblock'];?></a><br />
					</td>

				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_blocked'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
			</div>
			
			<div id="box_bottom">
			<table cellpadding="0" cellspacing="0" border="0" width="100%">
				<tr>
					<td align="left">
						<img src="<?php echo $templatePath;?>img/box_bottom_left.png" width="5" height="18" alt="" border="0" /><br />
					</td>
					<td align="left">
						<img src="<?php echo $templatePath;?>img/pixel.png" width="1" height="9" alt="" border="0" /><br />
					</td>
					<td align="right">
						<img src="<?php echo $templatePath;?>img/box_bottom_right.png" width="5" height="18" alt="" border="0" /><br />
					</td>
				</tr>
			</table>
			</div>
		</td>
	</tr>
</table>
</form>

==> aroundme_0_6_7.zip: aroundme_0_6_7/aroundme/template/barnraiser_01/sn_blocked.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>


<form action="sn_blocked.php" method="post">

<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_blocked'];?><br />
	</div>
	
	<div class="box_mid">
		<div class="content">
			<table border="0" cellspacing="0" cellpadding="4" width="100%">
				<?php
				if (isset($blocked)) {
				foreach($blocked as $key => $i):
				?>
				<tr>
					<td>
						<a href="sn_profile.php?user_id=<?php echo $i['user_id_blocked'];?>"><?php echo $i['profile_nic'];?></a><br />
					</td>
					<td>
						<?php echo $this->date->formatDate($i['block_datetime'], 1);?><br />
					</td>
					<td>
						<?php echo $i['block_description'];?><br />
					</td>
					<td align="right">
						<a href="sn_blocked.php?unblock_user_id=<?php echo $i['user_id_blocked'];?>"><?php echo $lang['href_unblock'];?></a><br />
					</td>

				</tr>
				<?php
				endforeach;
				}
				else {
				?>
				<tr>
					<td>
						<?php echo $lang['err_no_blocked'];?><br />
					</td>
				</tr>
				<?php
				}
				?>
			</table>
		</div>
	</div>
</div>
		
<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>
</form>
